import os
import os.path
from datetime import datetime
from random import randrange

dateTime = datetime.today().strftime("%Y-%m-%d_%H-%M-%S")
chmFch = os.path.realpath(__file__)
chmDss = os.path.dirname(chmFch)

inputFile = "205TF-CX80-Shaker_Input.txt"

textFile = open(f"{chmDss}/input/{inputFile}", "r", encoding="utf-8")
textRaw = textFile.read()

accentedLetters = {'Á': 'A\u0301',
                   'Ă': 'A\u0306',
                   'Ǎ': 'A\u030C',
                   'Â': 'A\u0302',
                   'Ä': 'A\u0308',
                   'À': 'A\u0300',
                   'Ā': 'A\u0304',
                   'Ą': 'A\u0328',
                   'Å': 'A\u030A',
                   'Ǻ': 'A\u030A\u0301',
                   'Ã': 'A\u0303',
                   'Ć': 'C\u0301',
                   'Č': 'C\u030C',
                   'Ç': 'C\u0327',
                   'Ĉ': 'C\u0302',
                   'Ċ': 'C\u0307',
                   'Ď': 'D\u030C',
                   'Ḍ': 'D\u0323',
                   'É': 'E\u0301',
                   'Ĕ': 'E\u0306',
                   'Ě': 'E\u030C',
                   'Ê': 'E\u0302',
                   'Ë': 'E\u0308',
                   'Ė': 'E\u0307',
                   'È': 'E\u0300',
                   'Ē': 'E\u0304',
                   'Ę': 'E\u0328',
                   'Ẽ': 'E\u0303',
                   'Ǵ': 'G\u0301',
                   'Ğ': 'G\u0306',
                   'Ǧ': 'G\u030C',
                   'Ĝ': 'G\u0302',
                   'Ģ': 'G\u0326',
                   'Ġ': 'G\u0307',
                   'Ḡ': 'G\u0304',
                   'Ḫ': 'H\u032E',
                   'Ĥ': 'H\u0302',
                   'Ḥ': 'H\u0323',
                   'Í': 'I\u0301',
                   'Ĭ': 'I\u0306',
                   'Ǐ': 'I\u030C',
                   'Î': 'I\u0302',
                   'Ï': 'I\u0308',
                   'İ': 'I\u0307',
                   'Ì': 'I\u0300',
                   'Ī': 'I\u0304',
                   'Į': 'I\u0328',
                   'Ĩ': 'I\u0303',
                   'Ĵ': 'J\u0302',
                   'Ǩ': 'K\u030C',
                   'Ķ': 'K\u0326',
                   'Ḵ': 'K\u0331',
                   'Ĺ': 'L\u0301',
                   'Ľ': 'L\u030C',
                   'Ļ': 'L\u0326',
                   'Ḷ': 'L\u0323',
                   'Ḹ': 'L\u0323\u0304',
                   'Ḻ': 'L\u0331',
                   'Ṁ': 'M\u0307',
                   'Ṃ': 'M\u0323',
                   'Ń': 'N\u0301',
                   'Ň': 'N\u030C',
                   'Ņ': 'N\u0326',
                   'Ṅ': 'N\u0307',
                   'Ṇ': 'N\u0323',
                   'Ṉ': 'N\u0331',
                   'Ñ': 'N\u0303',
                   'Ó': 'O\u0301',
                   'Ŏ': 'O\u0306',
                   'Ǒ': 'O\u030C',
                   'Ô': 'O\u0302',
                   'Ö': 'O\u0308',
                   'Ò': 'O\u0300',
                   'Ő': 'O\u030B',
                   'Ō': 'O\u0304',
                   'Ǫ': 'O\u0328',
                   'Õ': 'O\u0303',
                   'Ŕ': 'R\u0301',
                   'Ř': 'R\u030C',
                   'Ŗ': 'R\u0326',
                   'Ṝ': 'R\u0323\u0304',
                   'Ṟ': 'R\u0331',
                   'Ś': 'S\u0301',
                   'Š': 'S\u030C',
                   'Ş': 'S\u0327',
                   'Ŝ': 'S\u0302',
                   'Ș': 'S\u0326',
                   'Ṣ': 'S\u0323',
                   'Ť': 'T\u030C',
                   'Ţ': 'T\u0327',
                   'Ț': 'T\u0326',
                   'Ṭ': 'T\u0323',
                   'Ú': 'U\u0301',
                   'Ŭ': 'U\u0306',
                   'Ǔ': 'U\u030C',
                   'Û': 'U\u0302',
                   'Ü': 'U\u0308',
                   'Ǘ': 'U\u0308\u0301',
                   'Ǚ': 'U\u0308\u030C',
                   'Ǜ': 'U\u0308\u0300',
                   'Ǖ': 'U\u0308\u0304',
                   'Ù': 'U\u0300',
                   'Ű': 'U\u030B',
                   'Ū': 'U\u0304',
                   'Ų': 'U\u0328',
                   'Ů': 'U\u030A',
                   'Ũ': 'U\u0303',
                   'Ẃ': 'W\u0301',
                   'Ŵ': 'W\u0302',
                   'Ẅ': 'W\u0308',
                   'Ẁ': 'W\u0300',
                   'Ý': 'Y\u0301',
                   'Ŷ': 'Y\u0302',
                   'Ÿ': 'Y\u0308',
                   'Ẏ': 'Y\u0307',
                   'Ỳ': 'Y\u0300',
                   'Ȳ': 'Y\u0304',
                   'Ỹ': 'Y\u0303',
                   'Ź': 'Z\u0301',
                   'Ž': 'Z\u030C',
                   'Ż': 'Z\u0307',
                   'Ẓ': 'Z\u0323'}

textWithAccentedLetters = ""

for letter in textRaw:
    letter = letter.upper()

    if letter in accentedLetters:
        letter = accentedLetters[letter]
    textWithAccentedLetters += letter


fourSerifs = ["A", "H", "I", "M", "N", "V", "W", "E",
              "F", "K", "L", "T", "X", "Y"]
threeSerifs = ["P", "R"]
twoSerifs = ["B", "D", "C", "Ç", "G", "U", "Z", "S"]
oneSerif = ["Q", "J"]

textWithSerifs = ""

for letter in textWithAccentedLetters:

    textWithSerifs += letter

    if letter in fourSerifs:
        for i in range(4):
            textWithSerifs += str(randrange(4))

    elif letter in threeSerifs:
        for i in range(3):
            textWithSerifs += str(randrange(4))
    elif letter in twoSerifs:
        for i in range(2):
            textWithSerifs += str(randrange(4))

    elif letter in oneSerif:
        textWithSerifs += str(randrange(4))


with open(f"{chmDss}/output/205TF-CX80-Shaker_Output_{dateTime}.txt", "w") as f:
    f.write(textWithSerifs)
